import setuptools

setuptools.setup(
    name="delete-chrome-history-py",
    version="0.1.7",
    author="Bhavesh Bhatt",
    author_email="bhattbhavesh91@gmail.com",
    description="Delete specific websites from Google Chrome using Python",
    py_modules=["chrome_delete"],
    url="https://github.com/bhattbhavesh91/delete-chrome-history",
    install_requires=[],
)
